@@ -8,7 +8,7 @@ __all__ = [
             ]
 
 
-import array
+from array import array
 import rootplotlib as rpl
 import ROOT
 #import root_numpy
@@ -24,31 +24,31 @@ def new( name, xbins, xmin, xmax, ybins, ymin, ymax, title=''):
 
 def new2( name, xbins, ybins, title=''):
     if type(xbins) is list:
-        xbins = array.array('d', xbins)
+        xbins = array('d', xbins)
     elif type(xbins) is np.array:
-        xbins = array.array('d', xbins.tolist())
+        xbins = array('d', xbins.tolist())
     if type(ybins) is list:
-        ybins = array.array('d', ybins)
+        ybins = array('d', ybins)
     elif type(xbins) is np.array:
-        ybins = array.array('d', ybins.tolist())
+        ybins = array('d', ybins.tolist())
     return ROOT.TH2F(name, title, len(xbins)-1, xbins, len(ybins)-1, ybins)
 
 
 
 def fill( hist, xvalues, yvalues ):
 
-    w = array.array( 'd', np.ones_like( xvalues ) )
+    w = array( 'd', np.ones_like( xvalues ) )
 
     # treat x values
     if type(xvalues) is list:
         xvalues = array('d', xvalues)
-    elif type(xvalues) is np.array:
+    elif (type(xvalues) is np.array) or (type(xvalues) is np.ndarray):
         xvalues = array('d', xvalues.tolist())
 
     # treat y values
     if type(yvalues) is list:
         yvalues = array('d', yvalues)
-    elif type(xvalues) is np.array:
+    elif (type(xvalues) is np.array) or (type(xvalues) is np.ndarray):
         yvalues = array('d', yvalues.tolist())
 
     if len(xvalues) != len(yvalues):
@@ -113,6 +113,6 @@ def make_hist(name, xaxis_values, yaxis_values, xbins, xmin, xmax, ybins, ymin,
     # transform into a TH2F
     # create a TH2F to use
     hist = ROOT.TH2F( name, '', len(binx)-1, xmin, xmax, len(biny)-1, ymin, ymax)
-    fill(xaxis_values, yaxis_values)
+    fill(hist, xaxis_values, yaxis_values)
     #return root_numpy.array2hist(H, hist)
     return hist
\ No newline at end of file
